@@ -17,7 +17,9 @@ def evaluate_model():
     model.load_model(model_type=params["model_type"], model_dir=params["model_dir"])
     results = model.evaluate(test_df=test_df, metrics=params["metric"])
 
-    with dagshub_logger(metrics_path='reports/evaluation_metrics.csv', should_log_hparams=False) as logger:
+    with dagshub_logger(
+        metrics_path="reports/evaluation_metrics.csv", should_log_hparams=False
+    ) as logger:
         logger.log_metrics(results)
 
 
